package
Version:
v0.0.0-...-de9bdf8
Opens a new window with list of versions in this module.
Published: Jul 31, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Heap[T any] struct {
}
func (h *Heap[T]) Insert(value T, priority int)
Add item to the heap
Peek at the top item in the heap
Remove item from the heap.
Returns the item with the highest priority
type Sortable[T any] struct {
Value T
Priority int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.